<?php
/**
 * @file
 * Forms file for moneybird commerce module.
 * Defines the content of the forms included in the module
 * Written by Kevin Muller (kevin@enova-tech.net),
 * Cedric Alfonsi (cedric.alfonsi@enova-tech.net)
 * Updated by Robert Ragas (robert@goalgorilla.com)
 */

/**
 * Get the settings form for the module.
 *
 * The template part is buily dynamically from MoneyBird.
 * So if Moneybird is not accessible, an empty field is shown.
 */
function moneybird_commerce_settings_form_content() {
  $form['moneybird_commerce'] = array(
	'#type' => 'fieldset',
	'#collapsible' => FALSE,
	'#collapsed' => FALSE,
  );

  // API V2.
  $form['moneybird_commerce']['moneybird_commerce_redirect_uri'] = array(
	'#type' => 'textfield',
	'#title' => t('Redirect URI'),
	'#default_value' => variable_get('moneybird_commerce_redirect_uri', ''),
	'#size' => 60,
	'#maxlength' => 128,
	'#description' => t('Please fill in the absolute callback url as {yoursite}/moneybird_commerce/authorize. <br/> This same value is also required in the API token form in Moneybird.'),
	'#required' => true,
  );

  $form['moneybird_commerce']['moneybird_commerce_clientid'] = array(
	'#type' => 'textfield',
	'#title' => t('Client ID'),
	'#default_value' => variable_get('moneybird_commerce_clientid', ''),
	'#size' => 60,
	'#maxlength' => 128,
	'#description' => t('Please enter your client ID.'),
	'#required' => true,
  );

  $form['moneybird_commerce']['moneybird_commerce_clientsecret'] = array(
	'#type' => 'textfield',
	'#title' => t('Client Secret'),
	'#default_value' => variable_get('moneybird_commerce_clientsecret', ''),
	'#size' => 60,
	'#maxlength' => 128,
	'#description' => t('Please enter your client secret.'),
	'#required' => true,
  );

  $form['moneybird_commerce']['moneybird_commerce_administrationid'] = array(
	'#type' => 'textfield',
	'#title' => t('Administration ID'),
	'#default_value' => variable_get('moneybird_commerce_administrationid', ''),
	'#size' => 60,
	'#maxlength' => 128,
	'#description' => t('Please enter your administration ID.'),
	'#required' => true,
  );

  $form['moneybird_commerce_sync'] = array(
      '#type' => 'fieldset',
      '#collabsible' => FALSE,
      '#collapsed' => FALSE,
  );

  $form['moneybird_commerce_sync']['moneybird_commerce_cronjob'] = array(
      '#type' => 'checkbox',
      '#title' => t('Cron should be used for syncing the database.'),
      '#default_value' => variable_get('moneybird_commerce_cronjob', 1),
      '#description' => 'If not checked, you may always use the button below to sync the database.',
  );

  $form['moneybird_commerce_sync']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Sync the databases manually'),
      '#submit' => array('moneybird_commerce_sync_form_submit'),
  );

  return $form;
}

/**
 * Get the settings form for the module.
 *
 * The template part is buily dynamically from MoneyBird.
 * So if Moneybird is not accessible, an empty field is shown.
 */
function moneybird_commerce_invoice_settings_form_content() {
  if (variable_get('moneybird_commerce_accesstoken', '') != null) {
    $form['moneybird_commerce'] = array(
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );

    // The labels where the wrong way around. They are now changed.
    $form['moneybird_commerce']['moneybird_commerce_price_incl_taxes'] = array(
      '#type' => 'select',
      '#title' => t('Are the taxes already included in the prices sent to MoneyBird ?'),
      '#options' => array(
        '0' => t('No'),
        '1' => t('Yes'),
      ),
      '#default_value' => variable_get('moneybird_commerce_price_incl_taxes', 0),
      '#description' => t(
        'Select No if you do not wish MoneyBird to add taxes to the total price.'
      ),
    );

    $form['moneybird_commerce']['moneybird_notice'] = array(
      '#markup' => t('<h4>Notice: If you got multiple languages you can override the settings below through the <a href="@administer-page">rules UI</a>.</h4>', array(
        '@administer-page' => url('admin/config/workflow/rules'),
      )),
    );

    $form['moneybird_commerce']['moneybird_global_configuration'] = array(
      '#markup' => t('<h4><u>Global invoice configuration.</u></h4>'),
    );

    // Tax rate
    $form['moneybird_commerce']['moneybird_commerce_tax_rate'] = array(
      '#type' => 'select',
      '#title' => t('Tax rate'),
      '#options' => moneybird_commerce_get_tax_rates(),
      '#default_value' => variable_get('moneybird_commerce_tax_rate', ''),
      '#description' => t(
        'Choose the tax rate you want to use'
      ),
    );

    // Document style
    $form['moneybird_commerce']['moneybird_commerce_documentstyle'] = array(
      '#type' => 'select',
      '#title' => t('Document style'),
      '#options' => moneybird_commerce_get_document_styles(),
      '#default_value' => variable_get('moneybird_commerce_documentstyle', ''),
      '#description' => t(
        'Select the document style ( template )'
      ),
    );

    // Workflows
    $form['moneybird_commerce']['moneybird_commerce_workflows'] = array(
      '#type' => 'select',
      '#title' => t('Workflow'),
      '#options' => moneybird_commerce_get_workflows(),
      '#default_value' => variable_get('moneybird_commerce_workflows', ''),
      '#description' => t(
        'Select the workflow'
      ),
    );

    return $form;
  }
  else {
    $form['moneybird_commerce']['moneybird_notice'] = array(
      '#markup' => t('Please <a href="@administer-page">connect your Moneybird account</a> first before configuring invoice settings.', array(
        '@administer-page' => url('admin/config/moneybird_commerce/blocks'),
      )),
    );

    return $form;
  }
}